@@ -11,7 +11,8 @@ so reshape(1, -1) if necessary.
 
 import pandas as pd
 import numpy as np
-import scipy
+import scipy.signal
+import scipy.stats
 import warnings
 from sklearn import preprocessing
 
